SecureContentController class

Constructors

SecureContentController()

Properties

enabled bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable() Future<void>
dispose() Future<void>
enable({bool protectInAppSwitcher = true, Color appSwitcherColor = Colors.black}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProtection(bool enabled, {bool protectInAppSwitcher = true, Color appSwitcherColor = Colors.black}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited